@@ -1,4 +1,4 @@
-#!/usr/bin/env ruby
+#!/usr/bin/env ruby -r thread_tk
 # frozen_string_literal: false
 #
 #  TkTextIO class :: handling I/O stream on a TkText widget
@@ -395,6 +395,10 @@ class TkTextIO < TkText
 
   ####################################
 
+  def set_encoding(extern, intern = nil)
+    # not suppot -> do nothing
+  end
+
   def <<(obj)
     _write(obj)
     self
